@@ -1,9 +1,8 @@
 # plotting utilities for agnpy
-from pathlib import Path
 import matplotlib.pyplot as plt
 
 # axes labels
-sed_x_label = r"$\nu\,/\,Hz$"
+sed_x_label = r"$\nu\,/\,\mathrm{Hz}$"
 sed_y_label = r"$\nu F_{\nu}\,/\,(\mathrm{erg}\,\mathrm{cm}^{-2}\,\mathrm{s}^{-1})$"
 
 mpl_linewidth = 1.6
@@ -44,7 +43,7 @@ def plot_sed(nu, sed, ax=None, **kwargs):
     y_range : list of float
         lower and upper limit of the y axis limt
     comparison_range : list of float
-        plot the range over which the residuals were checked 
+        plot the range over which the residuals were checked
     """
     ax = plt.gca() if ax is None else ax
 
